Group {
  
  Core    = Region[ 801 ];
  Ind     = Region[ 802 ];
  Air     = Region[ 803 ];
  Armature= Region[ 804 ];
  
  
  //  Dirichlet_h   = Region[ 1010 ] ; Wrong
  Dirichlet_h   = Region[ 1000 ] ;
  Dirichlet_phi = Region[ 1000 ] ;
  SkinInd       = Region[ 900 ] ; // not used
  

  

  //  Domain     = Region[ {Air, Core, Ind, Armature, SkinInd} ] ; Wrong
  Domain     = Region[ {Air, Core, Ind, Armature} ] ;
  Domain_Inf = Region[ {} ] ;
  Domain_S   = Region[ {Ind} ] ;
  Domain_SC  = Region[ {SkinInd} ] ;
  Domain_M   = Region[ {} ] ;

  Val_Rint = 0.2 ;  
  Val_Rext = 0.3 ;

}


Function {

  mu0     = 4.e-7 * Pi ;
  murCore = 1000. ;
  

  nu [ Region[{Air, Ind}] ]  = 1. / mu0 ;
  nu [ Region[{Core,Armature}] ]  = 1. / (murCore * mu0) ;
  

  mu [ Region[{Air, Ind}] ]  = mu0 ;
  mu [ Region[ {Core,Armature}] ]  = murCore * mu0 ;
    
  js [ Ind ] = Vector[0, 0, 2.e6] ;
  
}


Constraint {

  // Two kinds of constraints on the source field hs:

  { Name h_fixed ; Type Assign;
    Case {
      { Region Dirichlet_h ; Value 0. ; } // for Dirichlet B.C.
    }
  }

  { Name h_gauge ; Type Assign;
    Case {
      { Region Domain; SubRegion Dirichlet_h ; Value 0. ; } // for gauge condition
    }
  }

  { Name phi ; Type Assign;
    Case {
      //      { Region Domain; SubRegion Dirichlet_phi ; Value 0. ; } Wrong
      { Region Dirichlet_phi; Value 0. ; } // phi is zero on surface Dirichlet_phi
    }
  }
    
}


Include "Magnetostat_Hconforming.pro"

eps = 1.e-5 ;

PostOperation {

  { Name Ph_H ; NameOfPostProcessing MagSta_Ph_H;
    Operation {
      //Print[ phi, OnElementsOf Domain, File "phi.pos"] ;
      Print[ b,   OnElementsOf Domain_S, File "b_phi.pos", Depth 0 ] ;
      Print[ nb,   OnElementsOf Domain_S, File "nb_phi.pos", Depth 1 ] ;
    }
  }

  { Name Ph_H2 ; NameOfPostProcessing MagSta_Ph_H;
    Operation {
      Print[ phi, OnElementsOf Domain, File "H_phi.pos"] ;
      Print[ b,   OnElementsOf Domain, File "H_b.pos" ] ;

      Print[ hs,   OnElementsOf Domain, File "H_hs.pos" ] ;
      Print[ js,   OnElementsOf Domain, File "H_js.pos" ] ;
    }
  }

e = 1e-8;

  { Name Section_H_b; NameOfPostProcessing MagSta_Ph_H;
    Operation {
      Print[ b, OnSection {{0,0,e}{1,0,e}{0,1,e}}, File "H_bsec.pos" ];
    }
  }

  { Name Line_H_b; NameOfPostProcessing MagSta_Ph_H;
    Operation {
      Print[ b, OnLine {{0,0.004,e}{0.01,0.004,e}}{300}, File "BH1.lin", Format Gnuplot ];
    }
  }

}
