
Jacobian {
  { Name JVol ;
    Case { 
      { Region Domain_Inf ; Jacobian VolSphShell{Val_Rint, Val_Rext} ; }
      { Region All ;        Jacobian Vol ; }
    }
  }
}


Integration {
  { Name Integr_1 ;
    Case { {Type Gauss ;
            Case { { GeoElement Triangle    ; NumberOfPoints  4 ; }
                   { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
                   { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
                   { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
                   { GeoElement Prism       ; NumberOfPoints  9 ; } }
           }
         }
  }
}


/* --------------------------------------------------------------------------
   MagSta_phi_hs : Magnetic H-conforming  formulation 
   -------------------------------------------------------------------------- */

FunctionSpace {
  { Name Hgrad_phi ; Type Form0 ;
    BasisFunction {
      { Name sn ; NameOfCoef phin ; Function BF_Node ;
        Support Domain ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef phin ; EntityType NodesOf ; NameOfConstraint phi ; }
    }
  }
  { Name Hcurl_hs ; Type Form1 ;
    BasisFunction {
      { Name se ; NameOfCoef he ; Function BF_Edge ;
      //        Support Domain_S ; Entity EdgesOf[ All, Not SkinInd ] ; } Wrong
        Support Domain ; Entity EdgesOf[ All ] ; }
      /*
      { Name sc ; NameOfCoef phic ; Function BF_GradGroupOfNodes ;
        Support Domain_SC ; Entity GroupsOfNodesOf[ All ] ; }
      { Name sc ; NameOfCoef phicc ; Function BF_GroupOfEdges ;
        Support Domain_S; Entity GroupsOfEdgesOnNodesOf[ SkinInd ] ; }
      */
    }
    Constraint {
      { NameOfCoef he ; EntityType EdgesOf; NameOfConstraint h_fixed ; }

      { NameOfCoef he ; EntityType EdgesOfTreeIn; EntitySubType StartingOn; 
        NameOfConstraint h_gauge ; }
      /*
      { NameOfCoef phic ; EntityType GroupsOfNodesOf ; NameOfConstraint phi ; }
      { NameOfCoef phicc ; EntityType GroupsOfNodesOf ; NameOfConstraint phi ; }
      */
    }
  }
}


Formulation {
  { Name MagSta_phi_hs ; Type FemEquation ;
    Quantity { 
      { Name phi ; Type Local ; NameOfSpace Hgrad_phi ; }
      { Name hs ; Type Local ; NameOfSpace Hcurl_hs ; }
    }
    Equation {
      Galerkin { [  mu[] * Dof{Grad phi} , {Grad phi} ] ;  
                 In Domain ; Jacobian JVol ; Integration Integr_1 ; }

      Galerkin { [  mu[] * Dof {hs} , {Grad phi} ] ;  
                 In Domain ; Jacobian JVol ; Integration Integr_1 ; }
                 
      Galerkin { [ Dof{Curl hs} , {Curl hs} ] ;  
                 In Domain ; Jacobian JVol ; Integration Integr_1 ; }

      Galerkin { [ - js[] , {Curl hs} ] ;  
                 In Domain_S ; Jacobian JVol ; Integration Integr_1 ; }
    }
  }
}


Resolution {
  { Name MagSta_phi_hs ;
    System {
      { Name Ph_H ; NameOfFormulation MagSta_phi_hs ; }
    }
    Operation { 
      Generate[Ph_H] ;  Solve[Ph_H] ; SaveSolution[Ph_H] ; 
    }
  }
}


PostProcessing {
  { Name MagSta_Ph_H ; NameOfFormulation MagSta_phi_hs ;
    Quantity {
      { Name b   ; Value { Local { [ mu[] * ({Grad phi}+{hs}) ] ; In Domain ; Jacobian JVol ; } 
                           /*Local { [ - mu[] * hc[] ]    ; In Domain_M ; Jacobian JVol ; }*/ } }
      { Name nb   ; Value { Local { [ Norm [mu[] * ({Grad phi}+{hs}) ] ]; In Domain ; Jacobian JVol ; } 
                            /*Local { [ Norm [ - mu[] * hc[] ] ]    ; In Domain_M ; Jacobian JVol ; }*/ } }
      { Name h   ; Value { Local { [ {d phi} ]        ; In Domain ; Jacobian JVol ; } } }
      { Name phi ; Value { Local { [ -{phi} ]            ; In Domain ; Jacobian JVol ; } } }


      { Name hs   ; Value { Local { [ {hs} ]        ; In Domain ; Jacobian JVol ; } } }
      { Name js   ; Value { Local { [ {d hs} ]        ; In Domain ; Jacobian JVol ; } } }

    }
  }
}
